ams.core.model.Model
====================

.. currentmodule:: ams.core.model

.. autoclass:: Model

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Model.alter
       
       
          ~Model.doc
       
       
          ~Model.get
       
       
          ~Model.get_idx
       
       
          ~Model.idx2uid
       
       
          ~Model.list2array
       
       
          ~Model.set
       
       
          ~Model.set_backref
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Model.class_name
   
   